==> rev-distro-2.0.2.tar.gz: igor-public/doc/html/navtreedata.js <==
var NAVTREE =
[
  [ "PEARL Procedures", "index.html", [
    [ "Introduction", "index.html", [
      [ "Installation", "index.html#sec_install", null ],
      [ "License Information", "index.html#sec_license", null ]
    ] ],
    [ "Angle-scan processing", "pag_anglescan_processing.html", [
      [ "Introduction", "pag_anglescan_processing.html#sec_intro", null ],
      [ "Data reduction", "pag_anglescan_processing.html#sec_import", [
        [ "Basic steps", "pag_anglescan_processing.html#sec_import_basics", null ],
        [ "Peak integration over linear background", "pag_anglescan_processing.html#sec_import_intlinbg", null ],
        [ "Peak fitting", "pag_anglescan_processing.html#sec_import_peakfit", null ],
        [ "Custom reduction functions", "pag_anglescan_processing.html#sec_import_custom", null ]
      ] ],
      [ "Normalization", "pag_anglescan_processing.html#sec_norm", [
        [ "Preparations", "pag_anglescan_processing.html#sec_norm_prep", null ],
        [ "Detector angle range", "pag_anglescan_processing.html#sec_norm_crop", null ],
        [ "Normalize detector angle", "pag_anglescan_processing.html#sec_norm_angle", null ],
        [ "Azimuthal variation (wobble)", "pag_anglescan_processing.html#sec_norm_wobble", null ],
        [ "Polar dependence", "pag_anglescan_processing.html#sec_norm_theta", null ]
      ] ],
      [ "Binning and plotting", "pag_anglescan_processing.html#sec_plot", [
        [ "Basic steps", "pag_anglescan_processing.html#sec_plot_basics", null ],
        [ "Refinements", "pag_anglescan_processing.html#sec_plot_refine", null ],
        [ "Interpolation", "pag_anglescan_processing.html#sec_plot_interp", null ],
        [ "Modulation function", "pag_anglescan_processing.html#sec_modulation", null ]
      ] ],
      [ "Data export", "pag_anglescan_processing.html#sec_export", [
        [ "Export picture", "pag_anglescan_processing.html#sec_export_plot", null ],
        [ "Export processed data", "pag_anglescan_processing.html#sec_export_data", null ]
      ] ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"fermi-edge-analysis_8ipf.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> rev-distro-2.1.1.tar.gz: igor-public/doc/html/navtreedata.js <==
var NAVTREE =
[
  [ "PEARL Procedures", "index.html", [
    [ "Introduction", "index.html", [
      [ "Introduction", "index.html#sec_intro", null ],
      [ "Installation", "index.html#sec_install", null ],
      [ "License Information", "index.html#sec_license", null ]
    ] ],
    [ "Projections", "_page_projections.html", null ],
    [ "Angle-scan processing", "pag_anglescan_processing.html", [
      [ "Introduction", "pag_anglescan_processing.html#sec_anglescan_intro", null ],
      [ "Data reduction", "pag_anglescan_processing.html#sec_import", [
        [ "Basic steps", "pag_anglescan_processing.html#sec_import_basics", null ],
        [ "Peak integration over linear background", "pag_anglescan_processing.html#sec_import_intlinbg", null ],
        [ "Peak fitting", "pag_anglescan_processing.html#sec_import_peakfit", null ],
        [ "Custom reduction functions", "pag_anglescan_processing.html#sec_import_custom", null ]
      ] ],
      [ "Normalization", "pag_anglescan_processing.html#sec_norm", [
        [ "Preparations", "pag_anglescan_processing.html#sec_norm_prep", null ],
        [ "Detector angle range", "pag_anglescan_processing.html#sec_norm_crop", null ],
        [ "Normalize detector angle", "pag_anglescan_processing.html#sec_norm_angle", null ],
        [ "Azimuthal variation (wobble)", "pag_anglescan_processing.html#sec_norm_wobble", null ],
        [ "Polar dependence", "pag_anglescan_processing.html#sec_norm_theta", null ]
      ] ],
      [ "Binning and plotting", "pag_anglescan_processing.html#sec_plot", [
        [ "Basic steps", "pag_anglescan_processing.html#sec_plot_basics", null ],
        [ "Refinements", "pag_anglescan_processing.html#sec_plot_refine", null ],
        [ "Interpolation", "pag_anglescan_processing.html#sec_plot_interp", null ],
        [ "Modulation function", "pag_anglescan_processing.html#sec_modulation", null ],
        [ "Projection", "pag_anglescan_processing.html#sec_projection", null ]
      ] ],
      [ "Data export", "pag_anglescan_processing.html#sec_export", [
        [ "Export picture", "pag_anglescan_processing.html#sec_export_plot", null ],
        [ "Export processed data", "pag_anglescan_processing.html#sec_export_data", null ]
      ] ]
    ] ],
    [ "Todo List", "todo.html", null ],
    [ "Packages", "modules.html", "modules" ],
    [ "Namespaces", null, [
      [ "Namespace List", "namespaces.html", "namespaces" ]
    ] ],
    [ "Data Structures", "annotated.html", "annotated" ],
    [ "Data Structure Index", "classes.html", null ],
    [ "Data Fields", "functions.html", [
      [ "All", "functions.html", null ],
      [ "Variables", "functions_vars.html", null ]
    ] ],
    [ "Files", null, [
      [ "File List", "files.html", "files" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"_page_projections.html",
"pearl-anglescan-tracker_8ipf.html#a35a5cd8a21b48be8d726c69eb5fca134",
"pearl-elog_8ipf_source.html"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
